@@ -1,10 +1,10 @@
 #' @details This function requires having a character vector with one or more valid Report Suites specified.
 #'
-#' @description Get Traffic Variables (props) Associated with a Report Suite(s). 
-#' 
-#' 
+#' @description Get Traffic Variables (props) Associated with a Report Suite(s).
+#'
+#'
 #' @title Get Traffic Variables (props) Associated with a Report Suite
-#' 
+#'
 #' @param reportsuite.ids report suite id (or list of report suite ids)
 #'
 #' @importFrom jsonlite toJSON
@@ -17,15 +17,20 @@
 #' @examples
 #' \dontrun{
 #' props <- GetProps("your_report_suite")
-#' 
+#'
 #' props2 <- GetProps(report_suites$rsid)
 #' }
 
 GetProps <- function(reportsuite.ids) {
-  
+
   request.body <- c()
   request.body$rsid_list <- reportsuite.ids
 
+  #Hack in locale, every method calls ApiRequest so this hopefully works
+  #Set encoding to utf-8 as well; if someone wanted to do base64 they are out of luck
+  request.body$locale <- unbox(AdobeAnalytics$SC.Credentials$locale)
+  request.body$elementDataEncoding <- unbox("utf8")
+
   valid.props <- ApiRequest(body=toJSON(request.body),func.name="ReportSuite.GetProps")
 
   props.formatted <- data.frame()
