@@ -41,4 +41,17 @@ cc <-QueueFallout("zwitchdev",
 #Validate returned value is a data.frame
 expect_is(cc, "data.frame")
 
+dd <- QueueFallout("zwitchdev",
+                  "2015-12-01",
+                  "2016-12-31",
+                  metrics="pageviews",
+                  element="page",
+                  checkpoints=c("http://randyzwitch.com/r-amazon-ec2", "http://randyzwitch.com/julia-import-data"),
+                  segment.id=c("5433e4e6e4b02df70be4ac63","54adfe3de4b02df70be5ea08"),
+                  enqueueOnly=TRUE
+                  )
+
+#Validate returned value is numeric
+expect_is(dd, "numeric")
+
 })
