@@ -158,5 +158,18 @@ test_that("Validate QueueRanked using legacy credentials", {
   #Validate returned value is a data.frame
   expect_is(ll, "data.frame")
 
+  # test enqueueOnly returns valid report id
+  mm <- QueueRanked("zwitchdev",
+                         date.from = "2016-04-01",
+                         date.to = "2016-04-20",
+                         metrics = "pageviews",
+                         elements = c("page", "sitesection", "browser") ,
+                         segment.id=c("5433e4e6e4b02df70be4ac63","54adfe3de4b02df70be5ea08"),
+                         enqueueOnly = TRUE
+  )
+
+
+  #Validate returned value is a numeric
+  expect_is(mm, "numeric")
 
 })
